|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r73039 - in sandbox/conversion/boost/conversion: . boost std
From: vicente.botet_at_[hidden]
Date: 2011-07-13 01:16:03
Author: viboes
Date: 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
New Revision: 73039
URL: http://svn.boost.org/trac/boost/changeset/73039
Log:
conversion: rename converter_cp by implicit_converter_cp
Text files modified:
sandbox/conversion/boost/conversion/assign_to.hpp | 2 +-
sandbox/conversion/boost/conversion/boost/array.hpp | 4 ++--
sandbox/conversion/boost/conversion/boost/chrono_duration_to_posix_time_duration.hpp | 8 ++++----
sandbox/conversion/boost/conversion/boost/chrono_time_point_to_posix_time_ptime.hpp | 4 ++--
sandbox/conversion/boost/conversion/boost/interval.hpp | 4 ++--
sandbox/conversion/boost/conversion/boost/optional.hpp | 8 ++++----
sandbox/conversion/boost/conversion/boost/rational.hpp | 4 ++--
sandbox/conversion/boost/conversion/implicit_convert_to.hpp | 22 +++++++++++-----------
sandbox/conversion/boost/conversion/is_extrinsically_convertible.hpp | 2 +-
sandbox/conversion/boost/conversion/std/complex.hpp | 2 +-
sandbox/conversion/boost/conversion/std/pair.hpp | 4 ++--
sandbox/conversion/boost/conversion/std/vector.hpp | 4 ++--
12 files changed, 34 insertions(+), 34 deletions(-)
Modified: sandbox/conversion/boost/conversion/assign_to.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/assign_to.hpp (original)
+++ sandbox/conversion/boost/conversion/assign_to.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -52,7 +52,7 @@
//! @tparam Source source type of the conversion.
//! @tparam Enable A dummy template parameter that can be used for SFINAE.
//!
- //! This class must be specialized by the user when the default behavior of @c explicit_converter is not satisfying.
+ //! This class must be specialized by the user when the default behavior of @c assigner is not satisfying.
template < typename Target, typename Source, class Enable = void>
struct assigner_cp : false_type {};
Modified: sandbox/conversion/boost/conversion/boost/array.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/boost/chrono_time_point_to_posix_time_ptime.hpp (original)
+++ sandbox/conversion/boost/conversion/boost/chrono_time_point_to_posix_time_ptime.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -62,7 +62,7 @@
namespace conversion {
template < class Clock, class Duration>
- struct converter_cp<posix_time::ptime, chrono::time_point<Clock, Duration>
+ struct implicit_converter_cp<posix_time::ptime, chrono::time_point<Clock, Duration>
> : true_type
{
posix_time::ptime operator()(const chrono::time_point<Clock, Duration>& from)
@@ -84,7 +84,7 @@
};
template < class Clock, class Duration>
- struct converter_cp<chrono::time_point<Clock, Duration>, posix_time::ptime
+ struct implicit_converter_cp<chrono::time_point<Clock, Duration>, posix_time::ptime
> : true_type
{
chrono::time_point<Clock, Duration> operator()(const posix_time::ptime& from)
Modified: sandbox/conversion/boost/conversion/boost/interval.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/is_extrinsically_convertible.hpp (original)
+++ sandbox/conversion/boost/conversion/is_extrinsically_convertible.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -36,7 +36,7 @@
*
*/
template <class Source, class Target>
- struct is_extrinsically_convertible : conversion::converter<
+ struct is_extrinsically_convertible : conversion::implicit_converter<
Target, Source
//typename remove_reference<typename remove_cv<Target>::type>::type,
//typename remove_reference<typename remove_cv<Source>::type>::type
Modified: sandbox/conversion/boost/conversion/std/complex.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/std/complex.hpp (original)
+++ sandbox/conversion/boost/conversion/std/complex.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -37,7 +37,7 @@
* Partial specialization of @c convert_to for @c std::complex of the same size
*/
template < class Target, class Source>
- struct converter_cp< std::complex<Target>, std::complex<Source>
+ struct implicit_converter_cp< std::complex<Target>, std::complex<Source>
BOOST_CONVERSION_REQUIRES((
is_extrinsically_convertible<Source,Target>::value
))
Modified: sandbox/conversion/boost/conversion/std/pair.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/boost/array.hpp (original)
+++ sandbox/conversion/boost/conversion/boost/array.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -38,12 +38,12 @@
namespace conversion {
/**
* Partial specialization of @c converter for @c boost::array of the same size
*
* !!!!!!!!!!!! boost::array is not constructible frome array<U,N> so this should be removed or replaced by explicit
*/
template < typename Target, typename Source, std::size_t N>
- struct converter_cp< array<Target,N>, array<Source,N>
+ struct implicit_converter_cp< array<Target,N>, array<Source,N>
#if defined(BOOST_CONVERSION_DOXYGEN_INVOKED)
, requires(
ExtrinsicallyAssignable<Target,Source>
@@ -38,12 +38,12 @@
namespace conversion {
/**
- * Partial specialization of @c converter for @c boost::array of the same size
+ * Partial specialization of @c implicit_converter for @c boost::array of the same size
*
* !!!!!!!!!!!! boost::array is not constructible frome array<U,N> so this should be removed or replaced by explicit
Modified: sandbox/conversion/boost/conversion/boost/chrono_duration_to_posix_time_duration.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/boost/chrono_duration_to_posix_time_duration.hpp (original)
+++ sandbox/conversion/boost/conversion/boost/chrono_duration_to_posix_time_duration.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -58,10 +58,10 @@
namespace conversion {
//! @brief @c converter specialization for conversions from @c boost::chrono::duration<> to @c boost::posix_time::time_duration.
//!
template < class Rep, class Period>
- struct converter_cp<posix_time::time_duration, chrono::duration<Rep, Period>
+ struct implicit_converter_cp<posix_time::time_duration, chrono::duration<Rep, Period>
> : true_type
{
//! @Returns the duration converted to seconds+nanoseconds following the boost::posix_time::time_duration formatting.
@@ -81,11 +81,11 @@
#endif
}
};
//! @brief @c converter specialization for conversions from @c boost::posix_time::time_duration to @c boost::chrono::duration<>.
//!
template < class Rep, class Period>
- struct converter_cp<chrono::duration<Rep, Period>, posix_time::time_duration
+ struct implicit_converter_cp<chrono::duration<Rep, Period>, posix_time::time_duration
> : true_type
{
//! @Returns the duration cast from a nanoseconds duration initialized to the total number of nanosecond of the @c from parameter.
@@ -58,10 +58,10 @@
namespace conversion {
- //! @brief @c converter specialization for conversions from @c boost::chrono::duration<> to @c boost::posix_time::time_duration.
+ //! @brief @c implicit_converter specialization for conversions from @c boost::chrono::duration<> to @c boost::posix_time::time_duration.
//!
template < class Rep, class Period>
@@ -81,11 +81,11 @@
}
};
- //! @brief @c converter specialization for conversions from @c boost::posix_time::time_duration to @c boost::chrono::duration<>.
+ //! @brief @c implicit_converter specialization for conversions from @c boost::posix_time::time_duration to @c boost::chrono::duration<>.
//!
template < class Rep, class Period>
Modified: sandbox/conversion/boost/conversion/boost/chrono_time_point_to_posix_time_ptime.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/boost/interval.hpp (original)
+++ sandbox/conversion/boost/conversion/boost/interval.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -29,10 +29,10 @@
namespace conversion {
//! @brief @c converter specialization for source and target been @c boost::numeric::interval.
//!
template < class Target, class PTarget, class Source, class PSource>
- struct converter_cp< numeric::interval<Target,PTarget>, numeric::interval<Source,PSource>
+ struct implicit_converter_cp< numeric::interval<Target,PTarget>, numeric::interval<Source,PSource>
#if defined(BOOST_CONVERSION_DOXYGEN_INVOKED)
, requires(
ExtrinsicallyConvertible<Source,Target>
@@ -29,10 +29,10 @@
namespace conversion {
- //! @brief @c converter specialization for source and target been @c boost::numeric::interval.
+ //! @brief @c implicit_converter specialization for source and target been @c boost::numeric::interval.
//!
template < class Target, class PTarget, class Source, class PSource>
Modified: sandbox/conversion/boost/conversion/boost/optional.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/boost/optional.hpp (original)
+++ sandbox/conversion/boost/conversion/boost/optional.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -37,10 +37,10 @@
namespace conversion {
/**
* Partial specialization of @c converter for boost::optional
*/
template < class Target, class Source>
- struct converter_cp
+ struct implicit_converter_cp
< optional<Target>, optional<Source>
#if defined(BOOST_CONVERSION_DOXYGEN_INVOKED)
, requires(
@@ -62,11 +62,11 @@
};
//! @brief @c converter specialization to try to convert the source to @c Target::value_type when @c Target is optional.
//!
//! We can see this specialization as a try_convert_to function.
template < class Target, class Source>
- struct converter_cp< optional<Target>, Source
+ struct implicit_converter_cp< optional<Target>, Source
#if defined(BOOST_CONVERSION_DOXYGEN_INVOKED)
, requires(
ExtrinsicallyConvertible<Source,Target>
@@ -37,10 +37,10 @@
namespace conversion {
/**
- * Partial specialization of @c converter for boost::optional
+ * Partial specialization of @c implicit_converter for boost::optional
*/
template < class Target, class Source>
@@ -62,11 +62,11 @@
};
- //! @brief @c converter specialization to try to convert the source to @c Target::value_type when @c Target is optional.
+ //! @brief @c implicit_converter specialization to try to convert the source to @c Target::value_type when @c Target is optional.
//!
//! We can see this specialization as a try_convert_to function.
Modified: sandbox/conversion/boost/conversion/boost/rational.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/boost/rational.hpp (original)
+++ sandbox/conversion/boost/conversion/boost/rational.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -35,10 +35,10 @@
namespace conversion {
//! @brief @c converter specialization for source and target been @c boost::rational.
//!
template < class Target, class Source>
- struct converter_cp< rational<Target>, rational<Source>
+ struct implicit_converter_cp< rational<Target>, rational<Source>
#if defined(BOOST_CONVERSION_DOXYGEN_INVOKED)
, requires(
ExtrinsicallyConvertible<Source,Target>
@@ -35,10 +35,10 @@
namespace conversion {
- //! @brief @c converter specialization for source and target been @c boost::rational.
+ //! @brief @c implicit_converter specialization for source and target been @c boost::rational.
//!
template < class Target, class Source>
Modified: sandbox/conversion/boost/conversion/implicit_convert_to.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/implicit_convert_to.hpp (original)
+++ sandbox/conversion/boost/conversion/implicit_convert_to.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -10,7 +10,7 @@
/**
* @file
* @brief Defines the free function @c implicit_convert_to and its customization point @c converter.
*
* The @c implicit_convert_to function converts the @c from parameter to a @c Target type.
*
@@ -62,9 +62,9 @@
//! @tparam Source source type of the conversion.
//! @tparam Enable A dummy template parameter that can be used for SFINAE.
//!
//! This class must be specialized by the user when the default behavior of @c explicit_converter is not satisfying.
template < typename Target, typename Source, class Enable = void >
- struct converter_cp : false_type {};
+ struct implicit_converter_cp : false_type {};
//! Default customization point for @c implicit_convert_to.
//!
@@ -72,19 +72,19 @@
//! @tparam Source source type of the conversion.
//! @tparam Enable A dummy template parameter that can be used for SFINAE.
//!
//! The default implementation relies on the @c converter_cp which must be specialized by the user.
template < typename Target, typename Source, class Enable = void >
- struct converter : converter_cp<Target,Source,Enable> {};
+ struct implicit_converter : implicit_converter_cp<Target,Source,Enable> {};
- //! Specialization for @c converter when @c is_convertible<Source,Target>.
+ //! Specialization for @c implicit_converter when @c is_convertible<Source,Target>.
//!
//! @tparam Target target type of the conversion.
//! @tparam Source source type of the conversion.
//!
//! @Requires @c is_convertible<Source,Target>
template < typename Target, typename Source >
- struct converter<Target, Source
+ struct implicit_converter<Target, Source
#if defined(BOOST_CONVERSION_DOXYGEN_INVOKED)
, requires(Convertible<Source,Target>)
#else
@@ -112,7 +112,7 @@
template < typename Target, typename Source >
Target implicit_convert_to(const Source& from, dummy::type_tag<Target> const&)
{
- return conversion::converter<Target,Source>()(from);
+ return conversion::implicit_converter<Target,Source>()(from);
}
}
@@ -137,8 +137,8 @@
//! @Params
//! @Param{source,source of the conversion}
//!
//! @Returns The result of @c converter customization point.
//! @Throws Whatever the @c converter call operator throws.
//!
//! @Example
//! @code
@@ -153,7 +153,7 @@
#if defined(BOOST_CONVERSION_DOUBLE_CP)
return boost::conversion::impl::convert_to_impl<Target>(from);
#else
- return conversion::converter<Target,Source>()(from);
+ return conversion::implicit_converter<Target,Source>()(from);
#endif
}
}
@@ -10,7 +10,7 @@
/**
* @file
- * @brief Defines the free function @c implicit_convert_to and its customization point @c converter.
+ * @brief Defines the free function @c implicit_convert_to and its customization point @c implicit_converter.
*
* The @c implicit_convert_to function converts the @c from parameter to a @c Target type.
@@ -62,9 +62,9 @@
//! @tparam Enable A dummy template parameter that can be used for SFINAE.
//!
- //! This class must be specialized by the user when the default behavior of @c explicit_converter is not satisfying.
+ //! This class must be specialized by the user when the default behavior of @c implicit_converter is not satisfying.
template < typename Target, typename Source, class Enable = void >
@@ -72,19 +72,19 @@
//! @tparam Enable A dummy template parameter that can be used for SFINAE.
//!
- //! The default implementation relies on the @c converter_cp which must be specialized by the user.
+ //! The default implementation relies on the @c implicit_converter_cp which must be specialized by the user.
template < typename Target, typename Source, class Enable = void >
@@ -137,8 +137,8 @@
//! @Param{source,source of the conversion}
//!
- //! @Returns The result of @c converter customization point.
- //! @Throws Whatever the @c converter call operator throws.
+ //! @Returns The result of @c implicit_converter customization point.
+ //! @Throws Whatever the @c implicit_converter call operator throws.
//!
//! @Example
Modified: sandbox/conversion/boost/conversion/is_extrinsically_convertible.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/std/pair.hpp (original)
+++ sandbox/conversion/boost/conversion/std/pair.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -35,10 +35,10 @@
// std namespace can not be overloaded
/**
* Partial specialization of @c converter_cp for @c std::pair of extrinsic convertibles.
*/
template < class T1, class T2, class S1, class S2>
- struct converter_cp< std::pair<T1,T2>, std::pair<S1,S2>
+ struct implicit_converter_cp< std::pair<T1,T2>, std::pair<S1,S2>
#if defined(BOOST_CONVERSION_DOXYGEN_INVOKED)
, requires(
ExtrinsicallyConvertible<S1,T1>
@@ -35,10 +35,10 @@
// std namespace can not be overloaded
/**
- * Partial specialization of @c converter_cp for @c std::pair of extrinsic convertibles.
+ * Partial specialization of @c implicit_converter_cp for @c std::pair of extrinsic convertibles.
*/
template < class T1, class T2, class S1, class S2>
Modified: sandbox/conversion/boost/conversion/std/vector.hpp
==============================================================================
--- sandbox/conversion/boost/conversion/std/vector.hpp (original)
+++ sandbox/conversion/boost/conversion/std/vector.hpp 2011-07-13 01:16:00 EDT (Wed, 13 Jul 2011)
@@ -38,10 +38,10 @@
// std namespace can not be overloaded
/**
* Partial specialization of @c converter_cp for @c std::vector of extrinsic convertibles.
*/
template < class T1, class A1, class T2, class A2>
- struct converter_cp< std::vector<T1,A1>, std::vector<T2,A2>
+ struct implicit_converter_cp< std::vector<T1,A1>, std::vector<T2,A2>
#if defined(BOOST_CONVERSION_DOXYGEN_INVOKED)
, requires
ExtrinsicallyAssignable<T1,T2>
@@ -38,10 +38,10 @@
// std namespace can not be overloaded
/**
- * Partial specialization of @c converter_cp for @c std::vector of extrinsic convertibles.
+ * Partial specialization of @c implicit_converter_cp for @c std::vector of extrinsic convertibles.
*/
template < class T1, class A1, class T2, class A2>
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk